/** @license
 * A thin wrapper around localStorage, with one key difference:
 * this allows the specification of the data's expiry (like cookies).
 * Each time LOCALstorage is accessed (through set(), get(), or remove()),
 * all expired data will be removed.
 * Only strings may be stored.
 * Copyright (c) 2010-2011 iNTERFACEWARE Inc.  All rights reserved.
 */

var LOCALstorage = {};
{
   var ONE_DAY_IN_MS = 24*60*60*1000;
   var LastExpiryCheck; // number of days since 1970/01/01.

   // current time, in ms, since 1970/01/01.
   function now(){
      return (new Date()).getTime();
   }
   
   // time in a specified number of days, in ms, since 1970/01/01.
   function nowPlusDays(Days){
      return now() + (Days * ONE_DAY_IN_MS);
   }
   
   function splitEntry(Entry){
      var i = Entry.indexOf(',');
      return [Entry.substring(0,i), Entry.substring(i+1)];
   }
   
   function clearExpired(){
      // For now, since we only support 'day' granularity, we
      // might as well just check for expired entries once a day.
      var Today = Math.floor(now() / ONE_DAY_IN_MS);
      if (Today === LastExpiryCheck) return;
      var Now = now();
      for (k in localStorage){
         try {
            var Entry = splitEntry(localStorage[k]);
            var Expiry = parseInt(Entry[0]);
            if (Expiry != NaN && Expiry < Now){
               localStorage.removeItem(k);
            }
         } catch (e) {
            // do nothing - format of localStorage key likely just
            // didn't match what we expected.
         }
      }
      LastExpiryCheck = Today;
   }
   
   ////////////////
   // Public API //
   ////////////////
   
   LOCALstorage.set = function(Name, Value, Days){
      if (!localStorage) return;
      clearExpired();
      // Write out the expiry in ms.  We could write out in
      // days, but we may want local_storage.js to be able
      // to support smaller granularity than days.
      localStorage[Name] = nowPlusDays(Days) + ',' + Value;
   };
   
   LOCALstorage.get = function(Name){
      if (!localStorage) return null;
      clearExpired();
      try {
         var Entry = splitEntry(localStorage[Name]);
         return Entry[1];
      } catch (e) {
         return null;
      }
   };
   
   LOCALstorage.remove = function(Name){
      if (!localStorage) return;
      clearExpired();
      delete localStorage[Name];
   };
};